# systemd-rpm-macros split out from systemd at Fedora 30
%if (0%{?fedora} && 0%{?fedora} <= 29) || 0%{?rhel}
%global systemd_rpm_macros systemd
%else
%global systemd_rpm_macros systemd-rpm-macros
%endif

Name:		pptp
Version:	1.10.0
Release:	22.0.cf%{?dist}
Summary:	Point-to-Point Tunneling Protocol (PPTP) Client
License:	GPL-2.0-or-later
URL:		http://pptpclient.sourceforge.net/
Source0:	http://downloads.sf.net/pptpclient/pptp-%{version}.tar.gz
Source1:	pptp-tmpfs.conf
Patch0:		pptp-1.10.0-man-fix.patch
BuildRequires:	coreutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	/usr/bin/pod2man
BuildRequires:	%{systemd_rpm_macros}
Requires:	ppp >= 2.4.2, /sbin/ip
Requires:	systemd

%description
Client for the proprietary Microsoft Point-to-Point Tunneling
Protocol, PPTP. Allows connection to a PPTP based VPN as used
by employers and some cable and ADSL service providers.

%package setup
Summary:	PPTP Tunnel Configuration Script
Requires:	%{name} = %{version}-%{release}

%description setup
This package provides a simple configuration script for setting up PPTP
tunnels.

%prep
%setup -q

# Fix man page and typo in the built-in help
%patch -P 0 -p1 -b .man-fix

# Pacify rpmlint
perl -pi -e 's/install -o root -m 555 pptp/install -m 755 pptp/;' Makefile

# Use /run rather than /var/run (#1722119)
perl -pi -e 's/\/var\/run\/pptp/\/run\/pptp/;' pptp_callmgr.h

%build
OUR_CFLAGS="-Wall %{optflags} -Wextra -Wstrict-aliasing=2 -Wnested-externs -Wstrict-prototypes"
%{make_build} CFLAGS="$OUR_CFLAGS" LDFLAGS="$RPM_LD_FLAGS" IP=/sbin/ip

%install
%{make_install} BINDIR=%{buildroot}%{_sbindir}
install -d -m 750 %{buildroot}/run/pptp

# Make sure /run/pptp exists at boot time for systems
# with /var/run on tmpfs (#656672)
install -d -m 755 %{buildroot}%{_tmpfilesdir}
install -p -m 644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/pptp.conf

%files
%license COPYING
%doc AUTHORS DEVELOPERS NEWS README TODO USING
%doc ChangeLog Documentation/DESIGN.PPTP PROTOCOL-SECURITY
%dir %attr(750,root,root) /run/pptp/
%{_tmpfilesdir}/pptp.conf
%{_sbindir}/pptp
%{_mandir}/man8/pptp.8*
%config(noreplace) %{_sysconfdir}/ppp/options.pptp

%files setup
%{_sbindir}/pptpsetup
%{_mandir}/man8/pptpsetup.8*

%changelog
* Sun Jan 19 2025 Paul Howarth <paul@city-fan.org> - 1.10.0-22.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Fri Jul 19 2024 Paul Howarth <paul@city-fan.org> - 1.10.0-21.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Tue Jan 30 2024 Paul Howarth <paul@city-fan.org> - 1.10.0-20.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Dec 13 2023 Paul Howarth <paul@city-fan.org> - 1.10.0-18.0.cf
- Rebuild to sync with Rawhide

* Fri Jul 21 2023 Paul Howarth <paul@city-fan.org> - 1.10.0-17.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jan 24 2023 Paul Howarth <paul@city-fan.org> - 1.10.0-16.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Jul 25 2022 Paul Howarth <paul@city-fan.org> - 1.10.0-15.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jan 24 2022 Paul Howarth <paul@city-fan.org> - 1.10.0-14.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Mon Jul 26 2021 Paul Howarth <paul@city-fan.org> - 1.10.0-13.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Feb  2 2021 Paul Howarth <paul@city-fan.org> - 1.10.0-12.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Sun Aug  2 2020 Paul Howarth <paul@city-fan.org> - 1.10.0-11.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Fri May 15 2020 Paul Howarth <paul@city-fan.org> - 1.10.0-10.0.cf
- Fix man page and typo in the built-in help

* Thu Feb  6 2020 Paul Howarth <paul@city-fan.org> - 1.10.0-9.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Jan 13 2020 Paul Howarth <paul@city-fan.org> - 1.10.0-8.0.cf
- Rebuild to sync with Rawhide

* Wed Jun 19 2019 Paul Howarth <paul@city-fan.org> - 1.10.0-7.0.cf
- Use /run rather than /var/run (#1722119)

* Tue Feb 12 2019 Paul Howarth <paul@city-fan.org> - 1.10.0-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 21 2018 Paul Howarth <paul@city-fan.org> - 1.10.0-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Feb 19 2018 Paul Howarth <paul@city-fan.org> - 1.10.0-3.0.cf
- EL-7 uses systemd

* Mon Feb  5 2018 Paul Howarth <paul@city-fan.org> - 1.10.0-2.0.cf
- Build with linker flags from redhat-rpm-config

* Thu Jan 18 2018 Paul Howarth <paul@city-fan.org> - 1.10.0-1.0.cf
- Update to 1.10.0
  - Assign copyright of contributed pptpsetup and routing.c to FSF
  - Remove inststr in favour of prctrl PR_SET_NAME
  - Vector tests: include in make, fix code rot, fix return status
  - pqueue: include missing sys/types.h
  - pptpsetup: prevent world-readable peers file, use three-argument append,
    allow password trailing spaces, split prints to chap-secrets, allow
    passwords with quotes, use absolute path to pptp
  - Remove uid from ip route get output; iproute2-4.10 and later may emit uid

* Mon Aug 14 2017 Paul Howarth <paul@city-fan.org> - 1.9.0-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Fri Jul 28 2017 Paul Howarth <paul@city-fan.org> - 1.9.0-3.0.cf
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Tue Nov 29 2016 Paul Howarth <paul@city-fan.org> - 1.9.0-1.0.cf
- Update to 1.9.0
  - Close a memory leak in pqueue
  - Avoid spurious error about /bin/ip on FreeBSD
  - Fix compiler warnings
  - Avoid clobbering heap (#1183627)
  - Fix use after free in call close request handler
  - Make clean to clean pptpsetup.8 (Debian #831032)
  - Add --missing-window option (Debian #680455, Ubuntu #681617)
  - Randomise call-id (Debian #721963)
  - Replace gethostbyname(3) with getaddrinfo(3)
  - Fix typo in pptp_ctrl manpage
  - Place pptpsetup manpage in correct section
  - Don't set build flags; use defaults
  - Remove pptpsetup.8 from source as it is generated
  - Fix for (null) in "pptp: GRE-to-PPP gateway on (null)"
- All patches now upstream or redundant

* Wed Aug  3 2016 Paul Howarth <paul@city-fan.org> - 1.8.0-8.1.cf
- Specify build dependencies

* Thu Feb 11 2016 Paul Howarth <paul@city-fan.org> - 1.8.0-8.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 24 2015 Paul Howarth <paul@city-fan.org> - 1.8.0-7.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Jan 25 2015 Paul Howarth <paul@city-fan.org> - 1.8.0-6.0.cf
- Replaced call-init-fix patch by vector-remove-fix patch from upstream
  (#1183627)
- Fixed one deref-after-free (by call-use-after-free-fix patch)

* Thu Jan 22 2015 Paul Howarth <paul@city-fan.org> - 1.8.0-5.0.cf
- Fix initialization of the call structure (#1183627)

* Wed Aug 20 2014 Paul Howarth <paul@city-fan.org> - 1.8.0-4.0.cf
- Use %%license where possible

* Thu Aug 14 2014 Paul Howarth <paul@city-fan.org> - 1.8.0-3.0.cf
- Rebuild for ppp 2.4.7 in F-21 onwards

* Wed Jun 11 2014 Paul Howarth <paul@city-fan.org> - 1.8.0-2.0.cf
- Drop %%defattr, redundant since rpm 4.4

* Wed Oct 23 2013 Paul Howarth <paul@city-fan.org> - 1.8.0-1.0.cf
- Update to 1.8.0
  - Options file, fix option documentation and links
  - Fix many warnings
  - Fix parallel build failure
  - Fix call disconnect notify
  - Add --nohostroute option to disable routing calls
  - Add --rtmark option for Linux policy routing
  - Move free of conn struct out of main loop
  - Avoid using conn struct after it is freed
  - Correct response to call disconnect notify
  - Avoid superfluous MPPE capability checks in pptpsetup
  - Retain permissions on chap-secrets, closes RH BZ #492090
  - Compilation fixes for older distributions of Linux
  - Port routing change feature for Solaris
  - Add IP_BINARY
  - Add include file build dependencies
- Drop all upstreamed patches

* Sun Aug  4 2013 Paul Howarth <paul@city-fan.org> - 1.7.2-22.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> - 1.7.2-21.0.cf
- Pointless rebuild for Perl 5.18 in Rawhide

* Thu Feb 14 2013 Paul Howarth <paul@city-fan.org> - 1.7.2-20.0.cf
- BR: /usr/bin/pod2man for generation of pptpsetup man page

* Thu Feb 14 2013 Paul Howarth <paul@city-fan.org> - 1.7.2-19.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Nov 27 2012 Paul Howarth <paul@city-fan.org> - 1.7.2-18.0.cf
- Don't hard-code /etc (#880574)

* Fri Aug 31 2012 Paul Howarth <paul@city-fan.org> - 1.7.2-17.0.cf
- Add note in options.pptp about MPPE not being available in FIPS mode
  (#845112)
- Add note in options.pptp about PPTP with MSCHAP-V2 being insecure

* Sat Jul 21 2012 Paul Howarth <paul@city-fan.org> - 1.7.2-16.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Jul  4 2012 Paul Howarth <paul@city-fan.org> - 1.7.2-15.0.cf
- Move tmpfiles.d config from %%{_sysconfdir} to %%{_prefix}/lib
- Drop support for old distributions prior to FC-3 (compiler flags)

* Wed Nov 30 2011 Paul Howarth <paul@city-fan.org> - 1.7.2-14.0.cf
- Add patch to fix highly-parallel build (e.g. -j16)
- Add additional compiler warning flags to highlight questionable code
- Add patch to fix comparisons between signed and unsigned integers
- Add patch to fix const usage
- Add patch to fix missing field initializers
- Add patch to suppress warnings about possibly unused variables
- Add patch to fix declarations that are not prototypes
- Add patch to fix warnings about nested externs
- Add patch to fix dubious typecasts that violate strict-aliasing rules
- FSF address patch accepted upstream
- Use default optimization level (-O2) again

* Fri Nov 11 2011 Paul Howarth <paul@city-fan.org> - 1.7.2-13.1.cf
- Merge patches for Call-Disconnect-Notify as per the Fedora package
- Drop compiler optimization level to -O0 as per upstream in attempt to
  resolve occasional segfault in pptpcm (#749455)

* Tue Nov  8 2011 Paul Howarth <paul@city-fan.org> 1.7.2-13.0.cf
- Patch to fix broken Call-Disconnect-Notify code accepted upstream
- Add upstream patch to support setting SO_MARK for the PPTP TCP control
  connection as well as on the GRE packets
- Add upstream patch to implement the --nohostroute option
- Update the FSF address references and GPLv2 license text
- Nobody else likes macros for commands

* Mon Feb 14 2011 Paul Howarth <paul@city-fan.org> - 1.7.2-12.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Nov 30 2010 Paul Howarth <paul@city-fan.org> - 1.7.2-11.0.cf
- Require systemd-units for ownership of /etc/tmpfiles.d directory

* Thu Nov 25 2010 Paul Howarth <paul@city-fan.org> - 1.7.2-10.3.cf
- Add /etc/tmpfiles.d/pptp.conf to create /var/run/pptp at boot time for
  systems with /var/run on tmpfs (#656672) [Fedora 15 onwards only]

* Thu Oct 28 2010 Paul Howarth <paul@city-fan.org> - 1.7.2-10.2.cf
- New call disconnect notify code looks good; drop the debug patch

* Thu Sep 30 2010 Paul Howarth <paul@city-fan.org> - 1.7.2-10.1.cf
- Attempt to fix broken call disconnect notify code

* Tue Jun 15 2010 Paul Howarth <paul@city-fan.org> - 1.7.2-10.0.cf
- Drop call disconnect notifications patch again
- Add some fixes from CVS:
  - Fix waitpid usage
  - Move free of connection struct out of main loop
  - Avoid using connection struct after it is freed

* Thu Nov 12 2009 Paul Howarth <paul@city-fan.org> - 1.7.2-9.2.cf
- Reinstate call disconnect notifications patch to see "bad" output

* Thu Nov 12 2009 Paul Howarth <paul@city-fan.org> - 1.7.2-9.1.cf
- Add patch to debug abort with call disconnect notifications patch
- Drop call disconnect notifications patch for now to see "good" output

* Tue Nov 10 2009 Paul Howarth <paul@city-fan.org> - 1.7.2-9.0.cf
- Add upstream patch to handle call disconnect notifications properly

* Thu Sep 24 2009 Paul Howarth <paul@city-fan.org> - 1.7.2-8.0.cf
- Split pptpsetup into subpackage to avoid perl dependency (#524972)

* Sun Aug  2 2009 Paul Howarth <paul@city-fan.org> - 1.7.2-7.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Jun  1 2009 Paul Howarth <paul@city-fan.org> - 1.7.2-6
- Don't check for MPPE capability in kernel and pppd unless we're creating a
  tunnel that requires encryption
- Don't check for MPPE capability in pppd at all because we require
  pppd >= 2.4.2, which includes MPPE support (#502967)

* Wed Mar 25 2009 Paul Howarth <paul@city-fan.org> - 1.7.2-5
- Retain permissions on /etc/ppp/chap-secrets when using pptpsetup (#492090)
- Use upstream versions of patches
- Re-enable parallel build; Makefile dependencies now fixed
- Use perl rather than sed to edit Makefile, for spec compatibility with
  ancient distro releases

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon May 19 2008 Paul Howarth <paul@city-fan.org> - 1.7.2-3
- Add dependency on /sbin/ip
- Disable parallel make - object files are missing dependency on config.h

* Mon May 19 2008 Paul Howarth <paul@city-fan.org> - 1.7.2-2
- Use /sbin/ip, not /bin/ip for routing

* Wed May 14 2008 Paul Howarth <paul@city-fan.org> - 1.7.2-1
- Update to 1.7.2
- New script and manpage: pptpsetup
- Add patch to remove reference to stropts.h, not shipped in F9 onwards

* Wed Feb 13 2008 Paul Howarth <paul@city-fan.org> - 1.7.1-4
- Rebuild with gcc 4.3.0 for Fedora 9

* Fri Aug 24 2007 Paul Howarth <paul@city-fan.org> - 1.7.1-3
- Change download URL from df.sf.net to downloads.sf.net
- Expand tabs in spec
- Clarify license as GPL version 2 or later

* Wed Aug 30 2006 Paul Howarth <paul@city-fan.org> - 1.7.1-2
- FE6 mass rebuild

* Mon Feb 13 2006 Paul Howarth <paul@city-fan.org> - 1.7.1-1
- New upstream version 1.7.1 (fixes #166394)
- Include new document PROTOCOL-SECURITY
- Cosmetic change: replace variables with macros

* Wed Aug 10 2005 Paul Howarth <paul@city-fan.org> - 1.7.0-2
- Own directory %%{_localstatedir}/run/pptp

* Thu Jul 28 2005 Paul Howarth <paul@city-fan.org> - 1.7.0-1
- New upstream version 1.7.0
- Remove patch, included upstream
- Edit Makefile to prevent attempted chown in %%install
- Remove redundant %%attr tag in %%files
- Honour $RPM_OPT_FLAGS
- Ensure directories have correct permissions

* Fri May 27 2005 Paul Howarth <paul@city-fan.org> - 1.6.0-5
- Bump and rebuild

* Tue May 17 2005 Paul Howarth <paul@city-fan.org> - 1.6.0-4
- Rebuild with dist tags

* Tue May 10 2005 Paul Howarth <paul@city-fan.org> - 1.6.0-3
- Fix URL for SOURCE0 not to point to a specific sf.net mirror

* Tue May 10 2005 Paul Howarth <paul@city-fan.org> - 1.6.0-2
- Weed out documentation useful only to developers
- Add dist tag
- Use full URL for SOURCE0
- Fix permissions on %%{_sbindir}/pptp

* Fri May  6 2005 Paul Howarth <paul@city-fan.org> - 1.6.0-1
- First build for Fedora Extras, based on upstream spec file
